package cn.estsh.i3plus.pojo.sweb.sqlpack;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.sweb.bean.*;
import cn.estsh.i3plus.pojo.sweb.modelbean.SwebPOForPubListEnterModel;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description : hql 封装
 * @Reference :
 * @Author : jack.lv
 * @CreateDate : 2019-04-01 17:59
 * @Modify:
 **/
public class SwebHqlPack {

    /**
     * 通用封装isValid、isDeleted等参数
     *
     * @param bean
     * @param hqlStr
     * @return
     */
    private static DdlPackBean buildHql(BaseBean bean, DdlPackBean hqlStr) {
        // 判断工厂代码是否为空
        if (StringUtils.isNotBlank(bean.getOrganizeCode())) {
            DdlPreparedPack.getStringEqualPack(bean.getOrganizeCode(), "organizeCode", hqlStr);
        }

        // 封装有效状态和删除状态
        Integer isValid = bean.getIsValid();
        //默认查有效数据
        if (isValid != null && isValid != 0) {
            DdlPreparedPack.getNumEqualPack(isValid, "isValid", hqlStr);
        } else {
            DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", hqlStr);
        }
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", hqlStr);
        return hqlStr;
    }

    public static DdlPackBean getPurchaseOrderWhereHql(SwebPurchaseOrder purchaseOrder) {
        DdlPackBean result = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(purchaseOrder.getOrderNo(), "orderNo", result);
        DdlPreparedPack.getStringEqualPack(purchaseOrder.getVendorCode(), "vendorCode", result);
        DdlPreparedPack.getNumEqualPack(purchaseOrder.getOrderStatus(), "orderStatus", result);
        return buildHql(purchaseOrder, result);
    }

    public static DdlPackBean getPackageWhereHql(SwebPackage swebPackage) {
        DdlPackBean result = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(swebPackage.getPackageNo(), "packageNo", result);
        DdlPreparedPack.getStringEqualPack(swebPackage.getParentPackageNo(), "parentPackageNo", result);
        DdlPreparedPack.getNumEqualPack(swebPackage.getPackTypeId(), "packTypeId", result);
        return buildHql(swebPackage, result);
    }

    public static DdlPackBean getPurchaseOrderDetailsWhereHql(SwebPOForPubListEnterModel model) {
        DdlPackBean result = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(model.getOrderNo(), "orderNo", result);
        DdlPreparedPack.getStringEqualPack(model.getVendorCode(), "vendorCode", result);
        DdlPreparedPack.getNumEqualPack(model.getOrderType(), "orderType", result);
        DdlPreparedPack.getStringEqualPack(model.getPartNo(), "partNo", result);
        DdlPreparedPack.timeBuilder(model.getRecTimeStart(), model.getRecTimeEnd(), "recTime", result, false);
        // 封装有效状态和删除状态
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", result);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", result);
        return buildHql(model, result);
    }

    public static DdlPackBean getProcurementPlanOrderWhereHql(SwebProcurementPlanOrder swebProcurementPlanOrder) {
        DdlPackBean result = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(swebProcurementPlanOrder.getVendorCode(), "vendorCode", result);
        DdlPreparedPack.getStringLikerPack(swebProcurementPlanOrder.getOrderNo(), "orderNo", result);
        return buildHql(swebProcurementPlanOrder, result);
    }

    public static DdlPackBean getProcurementPlanOrderDeatilsWhereHql(SwebProcurementPlanOrderDetails swebProcurementPlanOrderDetails) {
        DdlPackBean result = new DdlPackBean();
        DdlPreparedPack.getStringLikerPack(swebProcurementPlanOrderDetails.getOrderNo(), "orderNo", result);
        return buildHql(swebProcurementPlanOrderDetails, result);
    }

    public static DdlPackBean getVendorRelWhereHql(SwebVendorRel vendorRel) {
        DdlPackBean result = new DdlPackBean();
        DdlPreparedPack.getStringLikerPack(vendorRel.getVendorCode(), "vendorCode", result);
        DdlPreparedPack.getStringLikerPack(vendorRel.getPlannerCode(), "plannerCode", result);
        return buildHql(vendorRel, result);
    }

    /*public static String getPurchaseOrderDetailsWhereHql(SwebPurchaseOrderDetails swebPurchaseOrderDetails) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringLikerPack(swebPurchaseOrderDetails.getOrderNo(), "orderNo", result);
        return buildHql(swebPurchaseOrderDetails, result);
    }*/
}
